@@ -4,10 +4,8 @@ import os
 from collections import Counter
 
 import numpy as np
-import pyvista as pv
 
 from ansys.mapdl.reader._binary_reader import c_read_record
-from ansys.mapdl.reader import _binary_reader
 from ansys.mapdl.reader.errors import NoDistributedFiles
 
 STRESS_TYPES = ['X', 'Y', 'Z', 'XY', 'YZ', 'XZ']
@@ -67,6 +65,16 @@ class AnsysBinary():
     """ANSYS binary file class"""
     filename = None
 
+    # read only file handle
+    _cfile = None
+
+    def __del__(self):
+        if self._cfile is not None:
+            try:
+                self._cfile.close()
+            except:
+                pass
+
     def read_record(self, pointer, return_bufsize=False):
         """Reads a record at a given position.
 
@@ -94,7 +102,42 @@ class AnsysBinary():
             words read.
 
         """
-        return c_read_record(self.filename, pointer, return_bufsize)
+
+        if self._cfile is not None:
+            record = self._cfile.read_record(pointer, return_bufsize)
+            return record
+
+        record = c_read_record(self.filename, pointer, return_bufsize)
+        return record
+
+    # def read_record(self, pointer, return_bufsize=False):
+    #     """Reads a record at a given position.
+
+    #     Because ANSYS 19.0+ uses compression by default, you must use
+    #     this method rather than ``np.fromfile``.
+
+    #     Parameters
+    #     ----------
+    #     pointer : int
+    #         ANSYS file position (n words from start of file).  A word
+    #         is four bytes.
+
+    #     return_bufsize : bool, optional
+    #         Returns the number of words read (includes header and
+    #         footer).  Useful for determining the new position in the
+    #         file after reading a record.
+
+    #     Returns
+    #     -------
+    #     record : np.ndarray
+    #         The record read as a ``n x 1`` numpy array.
+
+    #     bufsize : float, optional
+    #         When ``return_bufsize`` is enabled, returns the number of
+    #         words read.
+
+    #     """
+    #     return c_read_record(self.filename, pointer, return_bufsize)
 
 
 def read_binary(filename, **kwargs):
